@@ -28,7 +28,7 @@ class FileRegistry:
         elif kind == 'ticker':
             self.path = rootpath + '__Python/Premind_Light/Analytics/Analytics_Cloud/Analytics_Docker/data/FraudArb/Tickers' + path + '/'
         elif kind == 'wordanalysis':
-            self.path = rootpath + kind + "/" + path + '/'
+            self.path = rootpath + kind + path + '/'
 
         if ftype == "":
             self.fullpath = self.path + name
